==> IceWarpServer-9.1.0_RHEL5.tar.gz: html/webmail/client/inc/gw_others.js <==
function gw_others(){};

var _me = gw_others.prototype;

//********************************************************************************
//Základní GET funkce pro práci s gw_others
//********************************************************************************
//Vstup:  sResourceName ... jméno non-well-known resource
//        sDataSet      ... globální pole, kde jsou uloženy všechny resource
//Výstup: asociativní pole asociativních polí hodnot a přístupů
//********************************************************************************

_me.get = function(sResourceName,sDataSet,bAdmin,bTryGet)
{
	//Zadali jsem oba parametry?
	if (!sResourceName || !sDataSet)
		return false;

	var aResource = dataSet.get(sDataSet,[sResourceName]);
	var bEmpty = false;

	//Stahnout storage ze serveru je-li prazdny
	if (bTryGet && typeof aResource != 'object'){
		storage.library('wm_storage');
		var aRsc = WMStorage.get({'resources':[sResourceName]});
		if (aRsc[sResourceName] && typeof aRsc[sResourceName] == 'object' && count(aRsc[sResourceName]['ITEMS'])){
			aResource = aRsc[sResourceName];
			dataSet.add(sDataSet, [sResourceName], aResource, true);
			bEmpty = false;
		}
		aRsc = null;
	}

	//Není tento resource inicializovaný?
	if (typeof aResource != 'object' || !count(aResource['ITEMS'])){
		var aResource = {'ITEMS':[{'VALUES':{},'ATTRIBUTES':{'DONT_SEND':true}}],'ATTRIBUTES':{'DONT_SEND':true}};
		bEmpty = true;
	}

	//Pokusíme se jej inicializovat default hodnotami
	if (!(aResource = this.setDefault(sResourceName,aResource,sDataSet,bEmpty)))
		return false;
/*
if (sResourceName.toLowerCase() == 'layout_settings')
	alert(typeof aResource.ITEMS[0].VALUES.LANGUAGE.VALUE);

	//inspect2(aResource.ITEMS[0].VALUES.LANGUAGE.VALUE,1);
*/

	var aAccess2Num = {'full':0,'view':1,'none':2};

	//Přístup na úrovni resource
	var sAccess = (aResource['ATTRIBUTES']['ACCESS'] ? aResource['ATTRIBUTES']['ACCESS'] : 'full');

	if (bAdmin) {
		var sUserAccess = (aResource['ATTRIBUTES']['USERACCESS'] ? aResource['ATTRIBUTES']['USERACCESS'] : 'full');
		var sDomainAdminAccess = (aResource['ATTRIBUTES']['DOMAINADMINACCESS'] ? aResource['ATTRIBUTES']['DOMAINADMINACCESS'] : 'full');
	}

	var aResourceFrame = aResource['ITEMS'][0];

	//Přístup na úrovni položky
	var sSubAccess = (aResourceFrame['ATTRIBUTES']['ACCESS'] ? aResourceFrame['ATTRIBUTES']['ACCESS'] : 'full');
	sAccess = (aAccess2Num[sAccess] >= aAccess2Num[sSubAccess] ? sAccess : sSubAccess);

	if (bAdmin) {
		var sUserSubAccess = (aResourceFrame['ATTRIBUTES']['USERACCESS'] ? aResourceFrame['ATTRIBUTES']['USERACCESS'] : 'full');
		var sDomainAdminSubAccess = (aResourceFrame['ATTRIBUTES']['DOMAINADMINACCESS'] ? aResourceFrame['ATTRIBUTES']['DOMAINADMINACCESS'] : 'full');
		sUserAccess = (aAccess2Num[sUserAccess] >= aAccess2Num[sUserSubAccess] ? sUserAccess : sUserSubAccess);
		sDomainAdminAccess = (aAccess2Num[sDomainAdminAccess] >= aAccess2Num[sDomainAdminSubAccess] ? sDomainAdminAccess : sDomainAdminSubAccess);
	}

	var aValues = aResourceFrame['VALUES'];
	var aResult = {'VALUES':{},'ACCESS':{}};
	var aValuesResult = aResult['VALUES'];
	var aAccessResult = aResult['ACCESS'];

	if (bAdmin) {
		var aUserAccessResult = aResult['USERACCESS'] = [];
		var aDomainAdminAccessResult = aResult['DOMAINADMINACCESS'] = [];
	}
	var sLCValue;

	//Procházíme jednotlivé hodnoty resource
	for(var sValue in aValues)
	{
		sLCValue = sValue.toLowerCase();
		aValuesResult[sLCValue] = aValues[sValue]['VALUE'];

		//Přístup na úrovni hodnoty
		sSubAccess = (aValues[sValue]['ATTRIBUTES']['ACCESS'] ? aValues[sValue]['ATTRIBUTES']['ACCESS'] : 'full');
		aAccessResult[sLCValue] = (aAccess2Num[sAccess] >= aAccess2Num[sSubAccess] ? sAccess : sSubAccess);

		if (bAdmin) {
			sUserSubAccess = (aValues[sValue]['ATTRIBUTES']['USERACCESS'] ? aValues[sValue]['ATTRIBUTES']['USERACCESS'] : 'full');
			aUserAccessResult[sLCValue] = (aAccess2Num[sUserAccess] >= aAccess2Num[sUserSubAccess] ? sUserAccess : sUserSubAccess);
			sDomainAdminSubAccess = (aValues[sValue]['ATTRIBUTES']['DOMAINADMINACCESS'] ? aValues[sValue]['ATTRIBUTES']['DOMAINADMINACCESS'] : 'full');
			aDomainAdminAccessResult[sLCValue] = (aAccess2Num[sDomainAdminAccess] >= aAccess2Num[sDomainAdminSubAccess] ? sDomainAdminAccess : sDomainAdminSubAccess);
		}
	}
	return aResult;
};

//********************************************************************************
//Základní SET funkce pro práci s gw_others
//********************************************************************************
//Vstup: sResourceName ... jméno non-well-known resource
//       aResourceInfo ... asociativních polí klíč -> hodnota
//       sDataSet      ... globální pole, kam se ukládají všechny resource
//********************************************************************************

_me.set = function(sResourceName,aResourceInfo,sDataSet,aAccess)
{
	//Zadali jsme všechny parametry?
	if (!sResourceName || typeof aResourceInfo != 'object' || !sDataSet)
		return false;

	var aResource = dataSet.get(sDataSet,[sResourceName]);
	//Je resource inicializovaný?
	if (typeof aResource == 'object' && count(aResource['ITEMS']))
	{
		var aResourceFrame = aResource['ITEMS'][0];
		var aValues = aResourceFrame['VALUES'];
		var bChange = false;
		var bLocalChange = false;
		var sUCValue;

		//Procházíme poslané hodnoty resource
		for(var sValue in aResourceInfo)
		{
			bLocalChange = false;
			sUCValue = sValue.toUpperCase();

			//Není hodnota inicializovaná?
			if (typeof aValues[sUCValue] != 'object')
				aValues[sUCValue] = {'ATTRIBUTES':{}};

			//Změnili jsme hodnotu?
			if (aValues[sUCValue]['VALUE'] != aResourceInfo[sValue]){
				aValues[sUCValue]['VALUE'] = aResourceInfo[sValue];
				bLocalChange = true;
			}
			if (aAccess) {

				if (aAccess['USERACCESS']) {
					var sUserAccess = (aValues[sUCValue]['ATTRIBUTES']['USERACCESS']) ? aValues[sUCValue]['ATTRIBUTES']['USERACCESS'] : 'full';
					var sNewUserAccess = (aAccess['USERACCESS'][sValue]) ? aAccess['USERACCESS'][sValue] : 'full';
					//Zmenili jsme opravneni?
					if (sUserAccess != sNewUserAccess) {
						aValues[sUCValue]['ATTRIBUTES']['USERACCESS'] = sNewUserAccess;
						bLocalChange = true;
					}
				}
				if (aAccess['DOMAINADMINACCESS']) {
					var sDomainAdminAccess = (aValues[sUCValue]['ATTRIBUTES']['DOMAINADMINACCESS']) ? aValues[sUCValue]['ATTRIBUTES']['DOMAINADMINACCESS'] : 'full';
					var sNewDomainAdminAccess = (aAccess['DOMAINADMINACCESS'][sValue]) ? aAccess['DOMAINADMINACCESS'][sValue] : 'full';

					//Zmenili jsme opravneni?
					if (sDomainAdminAccess != sNewDomainAdminAccess) {
						aValues[sUCValue]['ATTRIBUTES']['DOMAINADMINACCESS'] = sNewDomainAdminAccess;
						bLocalChange = true;
					}
				}
			}

			if (bLocalChange) {
				bChange = true;
				aValues[sUCValue]['ATTRIBUTES']['DEFAULT'] = false;
			}
		}
		//Máme nějaké změny?
		if (bChange)
		{
			aResource['ATTRIBUTES']['DONT_SEND'] = false;
			aResourceFrame['ATTRIBUTES']['DONT_SEND'] = false;
			dataSet.add(sDataSet,[sResourceName],aResource);
		}
	}
	else
	{
		aResource = {'ITEMS':[{'VALUES':{},'ATTRIBUTES':{'DONT_SEND':false}}],'ATTRIBUTES':{'DONT_SEND':false}};
		var aValues = aResource['ITEMS'][0]['VALUES'];

		//Procházíme poslané hodnoty resource
		for(var sValue in aResourceInfo)
			aValues[sValue.toUpperCase()] = {'VALUE':aResourceInfo[sValue],'ATTRIBUTES':{}};

		dataSet.add(sDataSet,[sResourceName],aResource);
	}
	return true;
};

// Zjednodusena verze funkce others.get.
// Implicitne pouziva dataset 'storage'
_me.getItem = function(sResourceName, sItemName){
	var rsc = GWOthers.get(sResourceName,'storage');
	
	//if(sItemName == 'language')
	
    return (rsc.VALUES && rsc.VALUES[sItemName])?rsc.VALUES[sItemName]:'';
};

_me.setDefault = function(sResourceName,aResource,sDataSet,bEmpty){
	var aValues = this.getDefaultValues(sResourceName);

	if (typeof aValues == 'object')
	{
		var aResourceValues = aResource['ITEMS'][0]['VALUES'];

		for(sValue in aValues)
			if (typeof aResourceValues[sValue] == 'undefined') // || typeof aResourceValues[sValue].VALUE == 'undefined' || typeof aResourceValues[sValue].VALUE === ''
				aResourceValues[sValue] = {'VALUE':aValues[sValue],'ATTRIBUTES':{'DEFAULT':true}};

		dataSet.add(sDataSet,[sResourceName],aResource);

		return aResource;
	}
	else
		if (bEmpty)
			return false;
		else
			return aResource;
};

_me.getDefaultValues = function(sResourceName)
{
	var aValues;

	switch(sResourceName){
		case 'MAIL_SETTINGS_DEFAULT':
			aValues = {'SPELLCHECKER':'en','HTML_MESSAGE':0,'READ_CONFIRMATION':0,'SAVE_SENT_MESSAGE':1,'ENCRYPT':0,'SIGN':0,'REPLY_TO_ADDRESS':'','PRIORITY':3,'CHARSET':'UTF-8'};
			break;

		case 'MAIL_SETTINGS_GENERAL':
			aValues = {'SOUND_NOTIFY':0,'AUTOUPDATE':0,'AUTOUPDATE_MINUTES':5,'MOVE_TO_TRASH':1,'FORWARD_MESSAGES':'inline','AUTOSAVE':1,'AUTOSAVE_MINUTES':5,'DEFAULT_FLAG':'1','AUTO_RECIPIENT_TO_ADDRESSBOOK':'0','AUTO_SHOW_IMAGES':'0'};
			break;

		case 'LAYOUT_SETTINGS':
			aValues = {'SKIN':'default','LANGUAGE':'en','DG_VIEW_LIMIT':30,'AB_VIEW_LIMIT':10,'LOGO':'logo.gif','DATE_FORMAT':0};
			break;

		case 'CALENDAR_SETTINGS':
			aValues = {'WEEK_BEGINS':'sunday','BEGIN_ON_TODAY':0,'DAY_BEGINS':8,'DAY_ENDS':16};
			break;

		case 'DEFAULT_CALENDAR_SETTINGS':
			aValues = {'EVENT_VIEW': 'week_view', 'EVENT_SHOW_AS': 'S', 'EVENT_SHARING': 'U', 'CONTACT_SHARING': 'U', 'JOURNAL_SHARING': 'U', 'NOTE_SHARING': 'U', 'TASK_SHARING': 'U'};
			break;

		case 'DEFAULT_REMINDER_SETTINGS':
			aValues = {'TIME':0,'RM_TYPE':'E','EMAIL':''};
			break;

		case 'DEFAULT_FOLDERS':
			aValues = {'SENT':sPrimaryAccount+'/Sent','TRASH':sPrimaryAccount+'/Trash','DRAFTS':sPrimaryAccount+'/Drafts', 'SPAM':sPrimaryAccount+'/Spam'};
			break;

		case 'READ_CONFIRMATION':
			aValues = {'TEXT':getLang('EMAIL::READING_CONFIRMATION'),'SUBJECT':getLang('EMAIL::READING_CONFIRMATION_SUBJECT')};
			break;

		case 'SIGNATURE':
			aValues = {'TEXT':'','TO_TOP':1};
			break;

		case 'LOGIN_DATA':
			aValues = {'IE_6_WARNING_SHOW_ON':0};
			break;

		case 'FORGOT_SETTINGS':
			aValues = {'FORGOT':0,'MAIL':getLang('EMAIL::FORGOT_PASSWORD')};
			break;
			
		case 'RESTRICTIONS':
			aValues = {'DISABLE_OTHERACCOUNTS':0,'DISABLE_CHANGEPASS':0};
			break;
	}

	return aValues;
};

var GWOthers = new gw_others();

==> IceWarpServer-9.4.1_RHEL5.tar.gz: html/webmail/client/inc/gw_others.js <==
function gw_others(){};

var _me = gw_others.prototype;

//********************************************************************************
//Základní GET funkce pro práci s gw_others
//********************************************************************************
//Vstup:  sResourceName ... jméno non-well-known resource
//        sDataSet      ... globální pole, kde jsou uloženy všechny resource
//Výstup: asociativní pole asociativních polí hodnot a přístupů
//********************************************************************************
_me.load = function(aResources,sDataSet,sDataPath){
	storage.library('wm_storage');
    sDataSet = sDataSet || 'storage';

	dataSet.add(sDataSet,sDataPath,WMStorage.get({'resources':aResources}));

	this.checkLayoutSettings(sDataSet,sDataPath);
};

_me.get = function(sResourceName,sDataSet,bAdmin,bTryGet)
{
	//Zadali jsem oba parametry?
	if (!sResourceName || !sDataSet)
		return false;

	var aResource = dataSet.get(sDataSet,[sResourceName]);
	var bEmpty = false;

	//Stahnout storage ze serveru je-li prazdny
	if (bTryGet && typeof aResource != 'object'){

		storage.library('wm_storage');
		var aRsc = WMStorage.get({'resources':[sResourceName]});
		if (aRsc[sResourceName] && typeof aRsc[sResourceName] == 'object' && count(aRsc[sResourceName]['ITEMS'])){
			aResource = aRsc[sResourceName];
			dataSet.add(sDataSet, [sResourceName], aResource, true);
			bEmpty = false;
		}
		aRsc = null;
	}

	//Není tento resource inicializovaný?
	if (typeof aResource != 'object' || !count(aResource['ITEMS'])){
		var aResource = {'ITEMS':[{'VALUES':{},'ATTRIBUTES':{'DONT_SEND':true}}],'ATTRIBUTES':{'DONT_SEND':true}};
		bEmpty = true;
	}

	//Pokusíme se jej inicializovat default hodnotami
	if (!(aResource = this.setDefault(sResourceName,aResource,sDataSet,bEmpty)))
		return false;
/*
if (sResourceName.toLowerCase() == 'layout_settings')
	alert(typeof aResource.ITEMS[0].VALUES.LANGUAGE.VALUE);
*/

	var aAccess2Num = {'full':0,'view':1,'none':2};

	//Přístup na úrovni resource
	var sAccess = (aResource['ATTRIBUTES']['ACCESS'] ? aResource['ATTRIBUTES']['ACCESS'] : 'full');

	if (bAdmin) {
		var sUserAccess = (aResource['ATTRIBUTES']['USERACCESS'] ? aResource['ATTRIBUTES']['USERACCESS'] : 'full');
		var sDomainAdminAccess = (aResource['ATTRIBUTES']['DOMAINADMINACCESS'] ? aResource['ATTRIBUTES']['DOMAINADMINACCESS'] : 'full');
	}

	var aResourceFrame = aResource['ITEMS'][0];

	//Přístup na úrovni položky
	var sSubAccess = (aResourceFrame['ATTRIBUTES']['ACCESS'] ? aResourceFrame['ATTRIBUTES']['ACCESS'] : 'full');
	sAccess = (aAccess2Num[sAccess] >= aAccess2Num[sSubAccess] ? sAccess : sSubAccess);

	if (bAdmin) {
		var sUserSubAccess = (aResourceFrame['ATTRIBUTES']['USERACCESS'] ? aResourceFrame['ATTRIBUTES']['USERACCESS'] : 'full');
		var sDomainAdminSubAccess = (aResourceFrame['ATTRIBUTES']['DOMAINADMINACCESS'] ? aResourceFrame['ATTRIBUTES']['DOMAINADMINACCESS'] : 'full');
		sUserAccess = (aAccess2Num[sUserAccess] >= aAccess2Num[sUserSubAccess] ? sUserAccess : sUserSubAccess);
		sDomainAdminAccess = (aAccess2Num[sDomainAdminAccess] >= aAccess2Num[sDomainAdminSubAccess] ? sDomainAdminAccess : sDomainAdminSubAccess);
	}

	var aValues = aResourceFrame['VALUES'];
	var aResult = {'VALUES':{},'ACCESS':{}};
	var aValuesResult = aResult['VALUES'];
	var aAccessResult = aResult['ACCESS'];

	if (bAdmin) {
		var aUserAccessResult = aResult['USERACCESS'] = [];
		var aDomainAdminAccessResult = aResult['DOMAINADMINACCESS'] = [];
	}
	var sLCValue;

	//Procházíme jednotlivé hodnoty resource
	for(var sValue in aValues)
	{
		sLCValue = sValue.toLowerCase();
		aValuesResult[sLCValue] = aValues[sValue]['VALUE'];

		//Přístup na úrovni hodnoty
		sSubAccess = (aValues[sValue]['ATTRIBUTES']['ACCESS'] ? aValues[sValue]['ATTRIBUTES']['ACCESS'] : 'full');
		aAccessResult[sLCValue] = (aAccess2Num[sAccess] >= aAccess2Num[sSubAccess] ? sAccess : sSubAccess);

		if (bAdmin) {
			sUserSubAccess = (aValues[sValue]['ATTRIBUTES']['USERACCESS'] ? aValues[sValue]['ATTRIBUTES']['USERACCESS'] : 'full');
			aUserAccessResult[sLCValue] = (aAccess2Num[sUserAccess] >= aAccess2Num[sUserSubAccess] ? sUserAccess : sUserSubAccess);
			sDomainAdminSubAccess = (aValues[sValue]['ATTRIBUTES']['DOMAINADMINACCESS'] ? aValues[sValue]['ATTRIBUTES']['DOMAINADMINACCESS'] : 'full');
			aDomainAdminAccessResult[sLCValue] = (aAccess2Num[sDomainAdminAccess] >= aAccess2Num[sDomainAdminSubAccess] ? sDomainAdminAccess : sDomainAdminSubAccess);
		}
	}
	return aResult;
};

//********************************************************************************
//Základní SET funkce pro práci s gw_others
//********************************************************************************
//Vstup: sResourceName ... jméno non-well-known resource
//       aResourceInfo ... asociativních polí klíč -> hodnota
//       sDataSet      ... globální pole, kam se ukládají všechny resource
//********************************************************************************

_me.set = function(sResourceName,aResourceInfo,sDataSet,aAccess)
{
	//Zadali jsme všechny parametry?
	if (!sResourceName || typeof aResourceInfo != 'object' || !sDataSet)
		return false;

	var aResource = dataSet.get(sDataSet,[sResourceName]);
	//Je resource inicializovaný?
	if (typeof aResource == 'object' && count(aResource['ITEMS']))
	{
		var aResourceFrame = aResource['ITEMS'][0];
		var aValues = aResourceFrame['VALUES'];
		var bChange = false;
		var bLocalChange = false;
		var sUCValue;

		//Procházíme poslané hodnoty resource
		for(var sValue in aResourceInfo)
		{
			bLocalChange = false;
			sUCValue = sValue.toUpperCase();

			//Není hodnota inicializovaná?
			if (typeof aValues[sUCValue] != 'object')
				aValues[sUCValue] = {'ATTRIBUTES':{}};

			//Změnili jsme hodnotu?
			if (aValues[sUCValue]['VALUE'] != aResourceInfo[sValue]){
				aValues[sUCValue]['VALUE'] = aResourceInfo[sValue];
				bLocalChange = true;
			}
			if (aAccess) {

				if (aAccess['USERACCESS']) {
					var sUserAccess = (aValues[sUCValue]['ATTRIBUTES']['USERACCESS']) ? aValues[sUCValue]['ATTRIBUTES']['USERACCESS'] : 'full';
					var sNewUserAccess = (aAccess['USERACCESS'][sValue]) ? aAccess['USERACCESS'][sValue] : 'full';
					//Zmenili jsme opravneni?
					if (sUserAccess != sNewUserAccess) {
						aValues[sUCValue]['ATTRIBUTES']['USERACCESS'] = sNewUserAccess;
						bLocalChange = true;
					}
				}
				if (aAccess['DOMAINADMINACCESS']) {
					var sDomainAdminAccess = (aValues[sUCValue]['ATTRIBUTES']['DOMAINADMINACCESS']) ? aValues[sUCValue]['ATTRIBUTES']['DOMAINADMINACCESS'] : 'full';
					var sNewDomainAdminAccess = (aAccess['DOMAINADMINACCESS'][sValue]) ? aAccess['DOMAINADMINACCESS'][sValue] : 'full';

					//Zmenili jsme opravneni?
					if (sDomainAdminAccess != sNewDomainAdminAccess) {
						aValues[sUCValue]['ATTRIBUTES']['DOMAINADMINACCESS'] = sNewDomainAdminAccess;
						bLocalChange = true;
					}
				}
			}

			if (bLocalChange) {
				bChange = true;
				aValues[sUCValue]['ATTRIBUTES']['DEFAULT'] = false;
			}
		}
		//Máme nějaké změny?
		if (bChange)
		{
			aResource['ATTRIBUTES']['DONT_SEND'] = false;
			aResourceFrame['ATTRIBUTES']['DONT_SEND'] = false;
			dataSet.add(sDataSet,[sResourceName],aResource);
		}
	}
	else
	{
		aResource = {'ITEMS':[{'VALUES':{},'ATTRIBUTES':{'DONT_SEND':false}}],'ATTRIBUTES':{'DONT_SEND':false}};
		var aValues = aResource['ITEMS'][0]['VALUES'];

		//Procházíme poslané hodnoty resource
		for(var sValue in aResourceInfo)
			aValues[sValue.toUpperCase()] = {'VALUE':aResourceInfo[sValue],'ATTRIBUTES':{}};

		dataSet.add(sDataSet,[sResourceName],aResource);
	}
	return true;
};

// Zjednodusena verze funkce others.get.
// Implicitne pouziva dataset 'storage'
_me.getItem = function(sResourceName, sItemName){
	var rsc = GWOthers.get(sResourceName,'storage');
    return (rsc.VALUES && rsc.VALUES[sItemName])?rsc.VALUES[sItemName]:'';
};

_me.setItem = function(sResourceName, sItemName, v){
	var tmp = {};
		tmp[sItemName] = v;
	var rsc = GWOthers.set(sResourceName,tmp,'storage');
};

_me.setDefault = function(sResourceName,aResource,sDataSet,bEmpty){
	var aValues = this.getDefaultValues(sResourceName);

	if (typeof aValues == 'object')
	{
		var aResourceValues = aResource['ITEMS'][0]['VALUES'];

		for(sValue in aValues)
			if (typeof aResourceValues[sValue] == 'undefined') // || typeof aResourceValues[sValue].VALUE == 'undefined' || typeof aResourceValues[sValue].VALUE === ''
				aResourceValues[sValue] = {'VALUE':aValues[sValue],'ATTRIBUTES':{'DEFAULT':true}};

		dataSet.add(sDataSet,[sResourceName],aResource);

		return aResource;
	}
	else
		if (bEmpty)
			return false;
		else
			return aResource;
};

_me.getDefaultValues = function(sResourceName)
{
	var aValues;

	switch(sResourceName){
		case 'SKINS':
			aValues = {'DEFAULT':'Default'};
			break;

		case 'MAIL_SETTINGS_DEFAULT':                                                                                                                                            //,'FROM':getPrimaryAccountFromAddress()
			aValues = {'SPELLCHECKER':'en','HTML_MESSAGE':0,'READ_CONFIRMATION':0,'SAVE_SENT_MESSAGE':1,'ENCRYPT':0,'SIGN':0,'REPLY_TO_ADDRESS':'','PRIORITY':3,'CHARSET':'UTF-8'};
			break;

		case 'MAIL_SETTINGS_GENERAL':
			aValues = {'SOUND_NOTIFY':0,'AUTOUPDATE':0,'AUTOUPDATE_MINUTES':5,'MOVE_TO_TRASH':1,'FORWARD_MESSAGES':'inline','AUTOSAVE':1,'AUTOSAVE_MINUTES':5,'DEFAULT_FLAG':'1','AUTO_RECIPIENT_TO_ADDRESSBOOK':'0','AUTO_SHOW_IMAGES':'0','AUTOCLEAR_TRASH_DAYS':'30'};
			break;

		case 'LAYOUT_SETTINGS':
			aValues = {'SKIN':'default','LANGUAGE':'en'/*,'DG_VIEW_LIMIT':30*/,'AB_VIEW_LIMIT':10,'LOGO':'logo.gif','DATE_FORMAT':0};
			break;

		case 'CALENDAR_SETTINGS':
			aValues = {'WEEK_BEGINS':'sunday','BEGIN_ON_TODAY':0,'DAY_BEGINS':8,'DAY_ENDS':16};
			break;

		case 'DEFAULT_CALENDAR_SETTINGS':
			aValues = {'EVENT_VIEW': 'week_view', 'EVENT_SHOW_AS': 'S', 'EVENT_SHARING': 'U', 'CONTACT_SHARING': 'U', 'JOURNAL_SHARING': 'U', 'NOTE_SHARING': 'U', 'TASK_SHARING': 'U'};
			break;

		case 'DEFAULT_REMINDER_SETTINGS':
			aValues = {'TIME':0,'RM_TYPE':'E','EMAIL':''};
			break;

		case 'DEFAULT_FOLDERS':
			aValues = {'SENT':sPrimaryAccount+'/Sent','TRASH':sPrimaryAccount+'/Trash','DRAFTS':sPrimaryAccount+'/Drafts', 'SPAM':sPrimaryAccount+'/Spam'};
			break;

		case 'READ_CONFIRMATION':
			aValues = {'TEXT':getLang('EMAIL::READING_CONFIRMATION'),'SUBJECT':getLang('EMAIL::READING_CONFIRMATION_SUBJECT')};
			break;

		case 'SIGNATURE':
			aValues = {'TEXT':'','TO_TOP':1};
			break;

		case 'LOGIN_DATA':
			aValues = {'IE_6_WARNING_SHOW_ON':0};
			break;

		case 'FORGOT_SETTINGS':
			aValues = {'FORGOT':0,'MAIL':getLang('FORGOT_PASS::EMAIL'),'SUBJECT':getLang('FORGOT_PASS::SUBJECT')};
			break;
			
		case 'RESTRICTIONS':
			aValues = {'DISABLE_OTHERACCOUNTS':0,'DISABLE_CHANGEPASS':0,'DISABLE_SIGNUP':1};
			break;
	}

	return aValues;
};

/**
 * this method hlelps to avoid loading of incorrect skins ale languages
 * it should be executed after each load of LAYOUT_SETTINGS
 **/
_me.checkLayoutSettings = function(sDataSet,sDataPath){

	//SKINs
	var aSkin = this.get('SKINS',sDataSet,sDataPath);
	if (aSkin){
		var aData = {};
		for (var i in aSkin['VALUES'])
			if (i != 'value')
				aData[i] = aSkin['VALUES'][i];

		if (!aData[this.getItem('LAYOUT_SETTINGS','skin')])
			this.setItem('LAYOUT_SETTINGS','skin',this.getDefaultValues('LAYOUT_SETTINGS').SKIN);
	}

	//LANGs
	var aLang = this.get('LANGUAGES',sDataSet,sDataPath);
	if (aLang){
		var aData = {};
		for (var i in aLang['VALUES'])
			aData[i] = aLang['VALUES'][i];

		if (!aData[this.getItem('LAYOUT_SETTINGS','language')])
			 this.setItem('LAYOUT_SETTINGS','language',this.getDefaultValues('LAYOUT_SETTINGS').LANGUAGE);
	}
};

var GWOthers = new gw_others();
